#
# spec file for package python-pytest-benchmark
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-pytest-benchmark
Version:        3.2.3
Release:        bp153.1.22
Summary:        A py.test fixture for benchmarking code
License:        BSD-2-Clause
URL:            https://github.com/ionelmc/pytest-benchmark
Source:         https://files.pythonhosted.org/packages/source/p/pytest-benchmark/pytest-benchmark-%{version}.tar.gz
Patch0:         fix-test-fast.patch
BuildRequires:  %{python_module aspectlib}
BuildRequires:  %{python_module elasticsearch}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module py-cpuinfo}
BuildRequires:  %{python_module pygaljs}
BuildRequires:  %{python_module pygal}
BuildRequires:  %{python_module pytest >= 3.8}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  git-core
%if %{with python2}
BuildRequires:  python-mock
BuildRequires:  python-pathlib2
BuildRequires:  python-statistics
%endif
BuildRequires:  python-rpm-macros
Requires:       python-py-cpuinfo
Requires:       python-pytest >= 3.8
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-aspectlib
Recommends:     python-elasticsearch
Recommends:     python-pygal
Recommends:     python-pygaljs
BuildArch:      noarch
%ifpython2
Requires:       python-pathlib2
Requires:       python-statistics
%endif
%python_subpackages

%description
A py.test fixture for benchmarking code. It will group the tests into
rounds that are calibrated to the chosen timer.

%prep
%setup -q -n pytest-benchmark-%{version}
%autopatch -p1
# skip cli tests as we use update-alternatives
rm -f tests/test_cli.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/pytest-benchmark
%python_clone -a %{buildroot}%{_bindir}/py.test-benchmark

%check
export PYTHONDONTWRITEBYTECODE=1
#%%pytest tests

%post
%{python_install_alternative pytest-benchmark py.test-benchmark}

%postun
%python_uninstall_alternative pytest-benchmark

%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license LICENSE
%python_alternative %{_bindir}/py.test-benchmark
%python_alternative %{_bindir}/pytest-benchmark
%{python_sitelib}/*

%changelog
* Fri Mar 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix buidling without python2
* Mon Jan 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.3:
  * Fixed "already-imported" pytest warning. Contributed by Jonathan Simon Prates in #151.
  * Fixed breakage that occurs when benchmark is disabled while using cprofile feature (by disabling cprofile too).
  * Dropped Python 3.4 from the test suite and updated test deps.
  * Fixed pytest_benchmark.utils.clonefunc to work on Python 3.8.
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Disable tests for now, the output from pytest changed quite a
  bit and upstream needs to adapt it for pytest5. The plugin
  actually works, it just fails its own testsuite...
* Thu May  9 2019 Matej Cepl <mcepl@suse.com>
- Add fix-test-fast.patch to avoid failing
  tests/test_normal.py::test_fast test on 32bit platform.
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Try to avoid messing up bytecode of the installed pkg
* Tue Mar 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add missing dependency on pygal and pygaljs
* Mon Mar 25 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add missing dependency on aspectlib
* Wed Feb 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.2.2:
  * Added support for pytest items without funcargs. Fixes interoperability with other pytest plugins like pytest-flake8.
  * Added missing version constraint change. Now pytest >= 3.8 is required (due to pytest 4.1 support).
  * Fixed couple CI/test issues.
  * Fixed broken pytest_benchmark.__version__.
  * Added support for simple trial x-axis histogram label. Contributed by Ken Crowell in #95).
  * Added support for Pytest 3.3+, Contributed by Julien Nicoulaud in #103.
  * Added support for Pytest 4.0. Contributed by Pablo Aguiar in #129 and #130.
  * Added support for Pytest 4.1.
  * Various formatting, spelling and documentation fixes. Contributed by Ken Crowell, Ofek Lev, Matthew Feickert, Jose Eduardo, Anton Lodder, Alexander Duryagin and Grygorii Iermolenko in #97, #97, #105, #110, #111, #115, #123, #131 and #140.
  * Fixed broken pytest_benchmark_update_machine_info hook. Contributed by Alex Ford in #109.
  * Fixed bogus xdist warning when using --benchmark-disable. Contributed by Francesco Ballarin in #113.
  * Added support for pathlib2. Contributed by Lincoln de Sousa in #114.
  * Changed handling so you can use --benchmark-skip and --benchmark-only, with the later having priority. Contributed by Ofek Lev in #116.
  * Fixed various CI/testing issues. Contributed by Stanislav Levin in #134, #136 and #138.
* Wed May  9 2018 toddrme2178@gmail.com
- Use license tag
- Implement update-alternatives
* Thu Oct 19 2017 toddrme2178@gmail.com
- Initial version
